<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package focus
 * @since focus 1.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @since focus 1.0
 */
function focus_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	return $classes;
}
add_filter( 'body_class', 'focus_body_classes' );

/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 *
 * @since focus 1.0
 */
function focus_enhanced_image_navigation( $url, $id ) {
	if ( ! is_attachment() && ! wp_attachment_is_image( $id ) )
		return $url;

	$image = get_post( $id );
	if ( ! empty( $image->post_parent ) && $image->post_parent != $id )
		$url .= '#main';

	return $url;
}
add_filter( 'attachment_link', 'focus_enhanced_image_navigation', 10, 2 );

if(!function_exists('focus_wp_title')) :
/**
 * Filter the title
 * @param $title
 * @param $sep
 * @param $seplocation
 * @return string
 *
 * @filter wp_title
 */
function focus_wp_title($title, $sep, $seplocation){
	if( is_feed() ) return $title;

	if(trim($sep) != ''){
		if(!empty($title)) {
			$title_array = explode($sep, $title);
		}
		else $title_array = array();

		$title_array[] = get_bloginfo('title');
		if(is_home()) $title_array[] = get_bloginfo('description');

		$title_array = array_map('trim', $title_array);
		$title_array = array_filter($title_array);

		if($seplocation == 'left') $title_array = array_reverse($title_array);

		$title = implode( " $sep ", $title_array );
	}

	return $title;
}
endif;
add_filter('wp_title', 'focus_wp_title', 10, 3);